@@ -8,7 +8,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: index.php,v 1.2 2007/01/21 08:12:18 seasonstream Exp $
+ * @version   CVS: $Id: index.php,v 1.3 2007/01/28 07:12:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Example2_Index
@@ -97,7 +97,7 @@ class Example2_Index
     {
         // åѥ᡼
         $session =& $request->getSessionObject();
-        $session->deleteParameterAll();
+        $session->deleteParameters();
 
         // ӥ塼Ϥѥ᡼򥻥åȡʺ줿ǧ
         $this->parameter1 = $session->getParameter('parameter1');
