@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.2 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.2 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
@@ -138,6 +138,7 @@ class SyL_ConfigLayouts extends SyL_Config
                 $this->config['file']       = $attribute['file'];
                 $this->config['templates']  = array();
                 $this->config['view']       = array();
+                $this->config['includes']   = array();
                 $this->config['parameters'] = array();
             }
             break;
@@ -154,6 +155,10 @@ class SyL_ConfigLayouts extends SyL_Config
                 $this->config['view'][$attribute['name']] = '';
                break;
 
+            case '/layouts/layout/includes/include':
+               $this->config['includes'][] = $attribute['file'];
+               break;
+
             case '/layouts/layout/parameters/parameter':
                $this->config['parameters'][$attribute['name']] = $attribute['value'];
                break;
