@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.6 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.7 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,25 +53,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.6 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.7 2007/02/17 14:28:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerWeb extends SyL_Controller
 {
-    /**
-     * ե륿ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $filter_file_name = 'filters.xml';
-    /**
-     * ե륿ե̾
-     *
-     * @access private
-     * @var string
-     */
-    var $action_file_name = 'actions.xml';
     /**
      * ¹Ƚ
      * 
