@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.6 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.7 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.6 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.7 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -195,6 +195,32 @@ class SyL_Response
         }
     }
 
+    /**
+     * gzip̤ѲǽʤѤ
+     * 
+     * @access public
+     * @param string ϥǡ
+     * @return bool true: gzip̡false: ̾
+     */
+    function convertGzip(&$data)
+    {
+        $convert = false;
+        if (extension_loaded('zlib')) {
+            if (isset($_SERVER['HTTP_ACCEPT_ENCODING']) && preg_match('/((x\-)?gzip)/', $_SERVER['HTTP_ACCEPT_ENCODING'], $matches)) {
+                SyL_Response::setHeader('Content-Encoding', $matches[1]);
+                SyL_Response::setHeader('Vary', 'Accept-Encoding');
+
+                $size = strlen($data);
+                $crc  = crc32($data);
+                $data = gzcompress($data, SYL_RESPONSE_GZIP);
+                $data = substr($data, 0, strlen($data) - 4);
+                $data = "\x1f\x8b\x08\x00\x00\x00\x00\x00" . $data . pack('V', $crc) . pack('V', $size);
+                $convert = true;
+            }
+        }
+        return $convert;
+    }
+
     /**
      * 󥰤줿HTML
      * 
@@ -206,10 +232,12 @@ class SyL_Response
         $data           = '';
         $content_type   = '';
         $content_length = false;
+        $gzip_compress  = false;
         if (is_object($view)) {
             $data           =& $view->getRender();
             $content_type   =  $view->getContentType();
             $content_length =  $view->isContentLength();
+            $gzip_compress  =  $view->isGzipCompress();
         } else {
             $data = $view;
         }
@@ -218,9 +246,13 @@ class SyL_Response
         if ($content_type) {
             SyL_Response::setHeader('Content-Type', $content_type);
         }
-        // ƥ̤򥻥å
-        if ($content_length) {
-            SyL_Response::setHeader('Content-Length', strlen($data));
+        
+        // gzip̤ѲǽʤѤ
+        if (!$gzip_compress || !$this->convertGzip($data)) {
+            // gzip̤ʤ硢ƥ̤򥻥å
+            if ($content_length) {
+                SyL_Response::setHeader('Content-Length', strlen($data));
+            }
         }
         // إå
         $this->sendHeader();
