@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.14 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.15 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.14 2007/02/17 14:28:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.15 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -76,7 +76,14 @@ class SyL_View
      * @access protected
      * @var bool
      */
-    var $content_length = false;
+    var $content_length = true;
+    /**
+     * gzipȽ
+     * 
+     * @access protected
+     * @var bool
+     */
+    var $gzip_compress = true;
     /**
      * ɽƤΥǡ
      * 
@@ -101,8 +108,6 @@ class SyL_View
     function SyL_View(&$dm)
     {
         $this->dm =& $dm;
-        // ǥХå٥ˤꡢcontent-lengthϤ뤫Ƚ
-        $this->content_length = (SYL_DEBUG < SYL_LOG_DEBUG);
     }
 
     /**
@@ -290,15 +295,22 @@ class SyL_View
      * ƥ̽Ƚ
      * 
      * @access public
-     * @param bool ƥ̽Ƚ
      * @return bool ƥ̽Ƚ
      */
-    function isContentLength($content_length=null)
+    function isContentLength()
     {
-        if (is_bool($content_length)) {
-            $this->content_length = ($content_length === true);
-        }
-        return $this->content_length;
+        return (SYL_RESPONSE_LENGTH) ? $this->content_length : false;
+    }
+
+    /**
+     * gzipȽ
+     * 
+     * @access public
+     * @return bool gzipȽ
+     */
+    function isGzipCompress()
+    {
+        return (SYL_RESPONSE_GZIP) ? $this->gzip_compress : false;
     }
 
     /**
