@@ -27,17 +27,11 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.9 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * ǥХåե饰
- * trueξ¹SQL˽񤭹
- */
-define( 'DB_DEBUG', false );
-
 /**
  *  DB饹
  *
@@ -45,7 +39,7 @@ define( 'DB_DEBUG', false );
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.8 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.9 2007/02/22 12:55:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -58,10 +52,10 @@ class SyL_DB
      */
     var $dbname = '';
     /**
-     * ͥ꥽
+     * ͥ꥽ or ֥
      * 
      * @access protected
-     * @var resource
+     * @var mixed
      */
     var $connection = null;
     /**
@@ -73,6 +67,7 @@ class SyL_DB
     var $transaction = false;
     /**
      * DB饤ȥ󥳡
+     * PHPȤƤʸ̾
      * 
      * @access protected
      * @var string
@@ -84,7 +79,7 @@ class SyL_DB
      * @access protected
      * @var string
      */
-    var $php_encode = '';
+    var $server_encode = '';
     /**
      * 󥳡Ѵơ֥
      * 
@@ -97,15 +92,12 @@ class SyL_DB
      * ե򻲾Ȥ
      * ե̾ʸʸ컲ȥե饰
      *
-     * MistaleϡCASE_UPPERΤб
-     * 
      * @access protected
      * @var string ʸ: CASE_UPPER
      *             ʸ: CASE_LOWER
      *             Τޤ  : ʶʸ
      */
-    // var $field_ref = '';
-    var $field_ref = CASE_UPPER;
+    var $field_case = CASE_UPPER;
 
     /**
      * tigger_errorȯե饰
@@ -114,13 +106,20 @@ class SyL_DB
      * @var bool
      */
     var $trigger_error_flag = true;
+    /**
+     * ǽ顼
+     * 
+     * @access protected
+     * @var string
+     */
+    var $last_error_code = '0';
     /**
      * ǽ顼å
      * 
      * @access protected
      * @var string
      */
-    var $last_error = '';
+    var $last_error_message = '';
     /**
      * Хå᥽å
      * 
@@ -137,38 +136,40 @@ class SyL_DB
      * @param string 饤ȥ󥳡
      * @param string С󥳡
      */
-    function SyL_DB($dbtype, $client_encode, $php_encode)
+    function SyL_DB($dbtype)
     {
         set_magic_quotes_runtime(0);
         $this->dbname = $dbtype;
-        $this->client_encode = $client_encode;
-        $this->php_encode    = $php_encode;
     }
 
     /**
      * SyL_DB饹Υ󥹥󥹼
      *
      * ˡ
-     *   $db =& SyL_DB::getInstance();
+     *   $conn =& SyL_DB::getConnection();
      *
      * $dsn = '[dbtype]:dbname=[dbname];host=[hostname];port=[port];user=[username];passwd=[password];client_encode=[client_encode];persistent=[persistent]';
      *
+     * PDOξdbtype
+     *   pdo.mysql
+     *
      * @access public
      * @param string ³ʸ
      */
-    function &getConnection($dsn, $php_encode='')
+    function &getConnection($dsn='', $server_encode='')
     {
         static $singleton = array();
-        if (!isset($singleton[$dsn])) {
-            $tmp = explode( ':', $dsn, 2 );
-            $dbtype = ucfirst($tmp[0]);
-            $dbname = '';
-            $user   = '';
-            $passwd = '';
-            $host   = '';
-            $port   = '';
-            $persistent    = '';
-            $client_encode = '';
+        if (!$dsn) {
+            if (!count($singleton)) {
+                trigger_error("[SyL error] Dsn not found.", E_USER_ERROR);
+            }
+            return current($singleton);
+        }
+
+        if (!isset($singleton[$dsn]) || !is_object($singleton[$dsn])) {
+            $tmp  = explode(':', $dsn, 2);
+            $type = ucfirst($tmp[0]);
+            $dbtype = $dbname = $user = $passwd = $host = $port = $persistent = $client_encode = '';
             if (isset($tmp[1])) {
                 $tmp = explode(';', $tmp[1]);
                 foreach ($tmp as $tmp2) {
@@ -177,11 +178,24 @@ class SyL_DB
                 }
             }
 
-            $class_name = 'SyL_DB_' . $dbtype;
+            if (!$dbtype) {
+                $dbtype = $type;
+            }
+
+            $class_name = 'SyL_DB' . $type;
+
             // ¥󥹥󥹺
             include_once dirname(__FILE__) . "/DB/{$class_name}.php";
-            $singleton[$dsn] = new $class_name($dbtype, $client_encode, $php_encode);
-            $singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent);
+            $singleton[$dsn] = new $class_name($dbtype);
+            if ($server_encode) $singleton[$dsn]->server_encode = $server_encode;
+            if ($client_encode) $singleton[$dsn]->client_encode = $client_encode;
+            if (!$singleton[$dsn]->openConnection($dbname, $user, $passwd, $host, $port, $persistent)) {
+                $singleton[$dsn] = null;
+            } else {
+                if ($client_encode) {
+                    $singleton[$dsn]->setClientEncoding($client_encode);
+                }
+            }
         }
         return $singleton[$dsn];
     }
@@ -214,30 +228,47 @@ class SyL_DB
      * DB饤¦ʸ󥳡ƥ
      * 
      * @access public
-     * @param string ʸ
+     * @param string DBʸ
+     * @param string PHP¦󥳡
      */
-    function setClientEncoding($client_encode='')
+    function setClientEncoding($client_encode, $server_encode='')
     {
-        if ($client_encode) {
-            $this->client_encode = $client_encode;
-        }
-        if ($this->client_encode) {
-            if (!$this->php_encode) {
-                foreach ($this->encode_table as $encode_table) {
-                    if ($encode_table[1] == strtolower($this->client_encode)) {
-                        $this->php_encode = $encode_table[0];
-                        break;
-                    }
-                }
-            }
-        } else if ($this->php_encode) {
-            foreach ($this->encode_table as $encode_table) {
-                if ($encode_table[0] == strtolower($this->php_encode)) {
-                    $this->client_encode = $encode_table[1];
-                    break;
-                }
+        $client_encode = strtolower($client_encode);
+        foreach ($this->encode_table as $encode_table) {
+            if ($encode_table[1] == $client_encode) {
+                $client_encode = $encode_table[0];
+                break;
             }
         }
+        $this->client_encode = $client_encode;
+
+        if ($server_encode) {
+            $this->server_encode = $server_encode;
+        }
+    }
+  
+    /**
+     * ѥ᡼˥̵˽
+     * 
+     * @access public
+     * @param string ˥оʸ
+     * @return string ˥ʸ
+     */
+    function escape($parameter)
+    {
+        return !is_numeric($parameter) ? addslashes($parameter) : $parameter;
+    }
+
+    /**
+     * ѥ᡼˥̵˽Likeʸ
+     * 
+     * @access public
+     * @param string ˥оʸ
+     * @return string ˥ʸ
+     */
+    function escapeLike($parameter)
+    {
+        return preg_replace('/(\_|\%)/', '\\\\$1', $this->escape($parameter));
     }
 
     /**
@@ -255,7 +286,7 @@ class SyL_DB
         } else if (is_int($value) || is_float($value)) {
             return $value;
         } else {
-            return "'" . $this->sanitize($value) . "'";
+            return "'" . $this->escape($value) . "'";
         }
     }
 
@@ -264,42 +295,18 @@ class SyL_DB
      * ˥¹Ԥ
      *
      * @access public
+     * @param string ̾
      * @param string ǡ
      * @return string SQLʸ
      */
-    function condition($value)
+    function condition($column, $value)
     {
         $value = $this->quote($value);
         if ($value == 'NULL') {
-            $value = ' IS ' . $value . ' ';
+            return "$column IS $value ";
         } else {
-            $value = ' = ' . $value . ' ';
+            return "$column = $value ";
         }
-        return $value;
-    }
-  
-    /**
-     * ѥ᡼˥̵˽
-     * 
-     * @access public
-     * @param string ˥оʸ
-     * @return string ˥ʸ
-     */
-    function sanitize($parameter)
-    {
-        return !is_numeric($parameter) ? addslashes($parameter) : $parameter;
-    }
-
-    /**
-     * ѥ᡼˥̵˽Likeʸ
-     * 
-     * @access public
-     * @param string ˥оʸ
-     * @return string ˥ʸ
-     */
-    function sanitizeLike($parameter)
-    {
-        return preg_replace('/(\_|\%)/', '\\\\$1', $this->sanitize($parameter));
     }
 
     /**
@@ -307,7 +314,7 @@ class SyL_DB
      *
      * @access public
      */
-    function begin()
+    function beginTransaction()
     {
         // SQL¸
         $this->log('begin');
@@ -324,7 +331,7 @@ class SyL_DB
      *
      * @access public
      */
-    function rollback()
+    function rollBack()
     {
         // SQL¸
         $this->log('rollback');
@@ -368,30 +375,44 @@ class SyL_DB
      * @param mixed ¹Է̷ޤDB꥽
      * @return boolean ¹OK: true, ¹NG: false
      */
-    function execute($sql, &$result)
+    function execRef($sql, &$result)
     {
         // SQL¸
         $this->log($sql);
 
         // ᥽å̾
-        list($method) = explode( ' ', $sql, 2 );
+        list($method) = explode(' ', $sql, 2);
 
         // SQL¹
         $result = false;
         switch (strtolower($method)) {
-        case 'select':
-            $result = $this->executeSelect($sql);
-            break;
+        case 'select': $result = $this->execSelect($sql); break;
         case 'insert':
         case 'update':
-        case 'delete':
-            $result = $this->executeUpdate($sql);
-            break;
-        default:
-            $result = $this->executeNoReturn($sql);
-            break;
+        case 'delete': $result = $this->execUpdate($sql); break;
+        default:       $result = $this->execNoReturn($sql); break;
         }
-        return ($result === false) ? false : true;
+        return ($result !== false);
+    }
+
+    /**
+     * SQL¹Ԥ̼
+     * 
+     * SQLʸselectξ
+     *   ¹Է̤꥽ȤƼ
+     * SQLʸinsert, update, deleteξ
+     *   ¹Է̱ƶ
+     * SQLʸ嵭ʳξ
+     *   ¹Ը塢true or falseֵ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @return mixed ¹Է̷ޤDB꥽
+     */
+    function exec($sql)
+    {
+        $this->execRef($sql, $result);
+        return $result;
     }
 
     /**
@@ -401,9 +422,9 @@ class SyL_DB
      * @param string SQLʸ
      * @return mixed ¹OK: DB꥽, ¹NG: false
      */
-    function &executeSelect($sql)
+    function execSelect($sql)
     {
-        trigger_error("[SyL error] executeSelect method not found ({$dbname})", E_USER_ERROR);
+        trigger_error("[SyL error] execSelect method not found ({$dbname})", E_USER_ERROR);
     }
 
     /**
@@ -413,9 +434,9 @@ class SyL_DB
      * @param string SQLʸ
      * @return mixed ¹OK: ¹Է̱ƶ, ¹NG: false
      */
-    function executeUpdate($sql)
+    function execUpdate($sql)
     {
-        trigger_error("[SyL error] executeUpdate method not found ({$dbname})", E_USER_ERROR);
+        trigger_error("[SyL error] execUpdate method not found ({$dbname})", E_USER_ERROR);
     }
 
     /**
@@ -425,9 +446,22 @@ class SyL_DB
      * @param string SQLʸ
      * @return boolean ¹OK: true, ¹NG: false
      */
-    function executeNoReturn($sql)
+    function execNoReturn($sql)
     {
-        trigger_error("[SyL error] executeNoReturn method is not found ({$dbname})", E_USER_ERROR);
+        trigger_error("[SyL error] execNoReturn method is not found ({$dbname})", E_USER_ERROR);
+    }
+
+    /**
+     * SQL¹Ԥ̥ǡ
+     *
+     * @access public
+     * @param string SQLʸ
+     * @return mixed ¹Է
+     */
+    function query($sql)
+    {
+        $this->queryRef($sql, $data, 'all');
+        return $data;
     }
 
     /**
@@ -447,12 +481,10 @@ class SyL_DB
      * @param string ̼ե饰
      * @return boolean ¹OK: true, ¹NG: false
      */
-    function executeGet($sql, &$data, $get='all') {}
+    function queryRef($sql, &$data, $get='all') {}
 
     /**
      * SQL¹Ԥڡ˥ǡ
-     * ¹ˡinitializePageץ᥽åɼ¹ɬ
-     * SQLʸΡFROM׶ľ˥ʸɬܡʤʳΥʸԲġ
      *
      * @access public
      * @param string SQLʸ
@@ -462,7 +494,24 @@ class SyL_DB
      * @param int ɽоݥڡ 
      * @return bool ¹Է
      */
-    function executePage($sql, &$result, &$page_control, $limit, $page=1) {}
+    function queryPageRef($sql, &$result, &$page_control, $limit, $page=1) {}
+
+    /**
+     * ڡ󥰥֥Ȥ
+     *
+     * @access public
+     * @param int 1ڡɽ
+     * @param int ɽоݥڡ 
+     * @return object ڡ󥰥֥
+     */
+    function &getPager($limit=20, $page=1)
+    {
+        include_once dirname(__FILE__) . '/SyL_Pager.php';
+        $pager = new SyL_Pager();
+        $pager->setCount($limit);
+        $pager->setPage($page);
+        return $pager;
+    }
 
     /**
      * Υѥ᡼ˡSQLDMLˤȤΩƼ¹Ԥ
@@ -485,7 +534,7 @@ class SyL_DB
      * @param string ѥ᡼update, deleteΤߡ
      * @return bool ¹Է true: OKfalse: 顼
      */
-    function executePerform($table, $columns, $action='insert', $where='')
+    function execPerform($table, $columns, $action='insert', $where='')
     {
         switch (strtolower($action)) {
         case 'insert':
@@ -554,27 +603,26 @@ class SyL_DB
             $sql = "DELETE FROM " . $table . " " . $where;
 
         default:
-          trigger_error("[SyL error] executePerform method is insert or update only", E_USER_ERROR);
+          trigger_error("[SyL error] queryPerform method is insert or update or delete only", E_USER_ERROR);
         }
 
-        return $this->execute($sql, $num);
+        return $this->exec($sql);
     }
 
-
     /**
-     * SyLȥɥץ㥪֥Ȥ
+     * Ǹ줿Ԥ ID 뤤ϥ󥹤ͤ
+     *
+     * ѤǤʤDBfalse֤
      *
      * @access public
-     * @param string ȥɥץ̾
-     * @return object SyLȥɥץ㥪֥
+     * @param string ̾
+     * @return int Ǹ줿ԤID
      */
-    function &getProcedureObject( $procedure_name )
+    function lastInsertId($seq='')
     {
-        $classname = 'SyL_DB_' . $this->dbname . '_Procedure';
-        include_once( $classname . '.php' );
-        return (new $classname( $this->connection, $procedure_name, $this->transaction ));
+        return false;
     }
-  
+
     /**
      * ȥꥬ顼ưǵưʤ褦
      *
@@ -591,44 +639,146 @@ class SyL_DB
      * ȥ󥶥ȯưʤ
      *
      * @access public
-     * @param string 顼å
      */
-    function executeTriggerError($error_message)
+    function triggerError()
     {
-        if (($this->transaction) || (!$this->trigger_error_flag)) {
-            $this->last_error = $error_message;
-        } else {
-            trigger_error($error_message, E_USER_ERROR);
+        if (!$this->transaction && $this->trigger_error_flag) {
+            trigger_error($this->getErrorMessage(), E_USER_ERROR);
         }
     }
 
+    /**
+     * 顼Ƚ
+     *
+     * @access public
+     * @return bool true: 顼ꡢfalse: 顼̵
+     */
+    function isError()
+    {
+        return ($this->last_error_code != '0');
+    }
+
+    /**
+     * Ǹ˵ä顼ɤ
+     *
+     * @access public
+     * @return string Ǹ˵ä顼
+     */
+    function errorCode()
+    {
+        return $this->last_error_code;
+    }
+
     /**
      * Ǹ˵ä顼å
      *
      * @access public
      * @return string Ǹ˵ä顼å
      */
-    function getLastErrorMessage()
+    function errorInfo()
     {
-        return $this->last_error;
+        return $this->last_error_message;
+    }
+
+    /**
+     * Ǹ˵ä顼å򥻥å
+     *
+     * @access public
+     * @param string 顼
+     * @param string 顼å
+     */
+    function setErrorMessage($code='', $message='')
+    {
+        $this->last_error_code    = $code;
+        $this->last_error_message = $message;
+    }
+
+    /**
+     * Ǹ˵ä顼å
+     *
+     * 顼Ƥʤϡ''
+     *
+     * @access public
+     * @return string Ǹ˵ä顼å
+     */
+    function getErrorMessage()
+    {
+        if ($this->errorInfo()) {
+            return $error_message = "[SyL DB Error " . $this->errorCode() . "] " . $this->errorInfo();
+        } else {
+            return '';
+        }
     }
 
     /**
      * ̥åΥե̾ʸޤϾʸȤˤ
      *
      * @access public
-     * @return array Ѵ
+     * @param array Ѵ
      * @return array Ѵ
      */
-    function changeFieldName($record)
+    function caseFieldName($record)
     {
-        if (is_array($record) && $this->field_ref) {
-            return array_change_key_case($record, $this->field_ref);
+        if (is_array($record) && $this->field_case) {
+            return array_change_key_case($record, $this->field_case);
         } else {
             return $record;
         }
     }
 
+    /**
+     * 󥳡ѴPHP => DBˤԤ
+     *
+     * (1) set names sjis
+     *    db     ?
+     *    client sjis
+     *    view   sjis
+     * (2) convertEncoding
+     *    encode
+     *    db     ?
+     *    client sjis  mb_convert_encoding($value, ?, 'sjis');
+     *    view   sjis
+     *    decode
+     *    db     ?
+     *    client sjis  mb_convert_encoding($value, 'sjis', ?);
+     *    view   sjis
+     * @access public
+     * @param mixed Ѵ
+     * @return mixed Ѵ
+     */
+    function convertEncoding(&$value)
+    {
+        if ($this->client_encode && $this->server_encode) {
+            if (is_array($value)) {
+                foreach ($value as $key => $value2) {
+                    $this->convertEncoding($value[$key]);
+                }
+            } else {
+                $value = mb_convert_encoding($value, $this->server_encode, $this->client_encode);
+            }
+        }
+    }
+
+    /**
+     * ǥѴDB => PHPˤԤ
+     *
+     * @access public
+     * @param mixed Ѵ
+     * @return mixed Ѵ
+     */
+    function convertDecoding(&$value)
+    {
+        if ($this->client_encode && $this->server_encode) {
+            if (is_array($value)) {
+                foreach ($value as $key => $value2) {
+                    $this->convertDecoding($value[$key]);
+                }
+            } else {
+                $value = mb_convert_encoding($value, $this->client_encode, $this->server_encode);
+            }
+        }
+    }
+
     /**
      * Хå᥽åɤ򥻥å
      *
@@ -644,6 +794,17 @@ class SyL_DB
         }
     }
 
+    /**
+     * ꥸʥ꥽ޤϥ֥Ȥ
+     *
+     * @access public
+     * @return mixed ꥸʥ꥽ޤϥ֥
+     */
+    function &getResource()
+    {
+        return $this->connection;
+    }
+
     /**
      * SQL¸
      *
@@ -656,75 +817,6 @@ class SyL_DB
             call_user_func($this->callback_log, $sql);
         }
     }
-
-    /**
-     * Ȥ³꥽
-     *
-     * @access public
-     * @return resource DB³꥽
-     */
-    function &getResourceConnection()
-    {
-        return $this->connection;
-    }
-
-    /**
-     * DB饹̾
-     *
-     * @access public
-     * @return string DB饹̾
-     */
-    function getDBName()
-    {
-        return $this->dbname;
-    }
-
-    /**
-     * ƥռؿ̾
-     *
-     * @access public
-     * @return string ƥռؿ̾
-     */
-    function getSqlSystemDate()
-    {
-        return 'CURRENT_TIMESTAMP';
-    }
-
-    /**
-     * եեޥåȴؿ̾
-     *
-     * @access public
-     *
-     * @param string ̾
-     * @param string շեޥå
-     * @return string եեޥåȴؿ̾
-     */
-    function getSqlDateFormat($column_name, $format) {}
-
-    /**
-     * ơ֥
-     *
-     * @access public
-     *
-     * @return array ơ֥ꥹ
-     */
-    function getTableList()
-    {
-        return array();
-    }
-
-    /**
-     * 
-     *
-     * @access public
-     *
-     * @param string ơ֥̾
-     * @return array ꥹ
-     */
-    function getColumnList( $table_name )
-    {
-        return array();
-    }
 }
 
 ?>
